@@ -2,7 +2,7 @@
 #
 # (c) 2002 - 2016, Arthur Corliss <corliss@digitalmages.com>,
 #
-# $Id: lib/Parse/PlainConfig.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
+# $Id: lib/Parse/PlainConfig.pm, 3.04 2017/02/06 02:58:13 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -23,7 +23,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-($VERSION) = ( q$Revision: 3.03 $ =~ /(\d+(?:\.(\d+))+)/sm );
+($VERSION) = ( q$Revision: 3.04 $ =~ /(\d+(?:\.(\d+))+)/sm );
 
 use Class::EHierarchy qw(:all);
 use Parse::PlainConfig::Constants qw(:all);
@@ -82,7 +82,7 @@ sub _initialize {
             foreach ( keys %_globals ) {
                 pdebug( 'overriding %s with (%s)',
                     PPCDLEVEL3, $_, $_globals{$_} );
-                $rv = 0 unless $settings->property( $_, $_globals{$_} );
+                $rv = 0 unless $settings->set( $_, $_globals{$_} );
             }
         }
     }
@@ -99,27 +99,27 @@ sub _initialize {
         }
 
         if ( scalar keys %_parameters ) {
-            $settings->property( 'property types', %_parameters );
+            $settings->set( 'property types', %_parameters );
             foreach ( keys %_parameters ) {
 
                 pdebug( 'creating property %s', PPCDLEVEL3, $_ );
                 unless (
-                    _declProp(
+                    _declProperty(
                         $obj,
+                        $_,
                         CEH_PUB | (
                             $_parameters{$_} == PPC_HDOC
                             ? PPC_SCALAR
                             : $_parameters{$_}
                             ),
-                        $_
                     )
                     ) {
                     $rv = 0;
                     last;
                 }
 
-                # Store property regex
-                $settings->store(
+                # merge property regex
+                $settings->merge(
                     'property regexes',
                     $_,
                     qr#(\s*)(\Q$_\E)\s*\Q@{[ $settings->delimiter ]}\E\s*(.*)#s
@@ -140,11 +140,11 @@ sub _initialize {
         }
 
         if ( scalar keys %_prototypes ) {
-            $settings->property( 'prototypes', %_prototypes );
+            $settings->set( 'prototypes', %_prototypes );
             foreach ( keys %_prototypes ) {
 
-                # Store property meta-data
-                $settings->store(
+                # merge property meta-data
+                $settings->merge(
                     'prototype regexes',
                     $_,
                     qr#(\s*)(\Q$_\E)\s+(\S+)\s*\Q@{[ $settings->delimiter ]}\E\s*(.*)#s
@@ -170,7 +170,7 @@ sub settings {
 
     my $obj = shift;
 
-    return $obj->relative('settings');
+    return $obj->getByAlias('settings');
 }
 
 sub default {
@@ -196,13 +196,13 @@ sub default {
         # Read in file
         while ( sip( $fn, @chunk ) and @chunk ) { push @lines, @chunk }
 
-        # Purge all lines prior to __DATA__
+        # empty all lines prior to __DATA__
         while ( @lines and $lines[0] !~ /^\s*__DATA__\s*$/s ) {
             shift @lines;
         }
         shift @lines;
 
-        # Purge all lines after __END__
+        # empty all lines after __END__
         if ( @lines and grep /^\s*__END__\s*$/s, @lines ) {
             while ( @lines and $lines[-1] !~ /^\s*__END__\s*$/s ) {
                 pop @lines;
@@ -232,7 +232,7 @@ sub get {
     pIn();
 
     if ( defined $p ) {
-        $valp = scalar grep /^\Q$p\E$/s, $obj->propertyNames;
+        $valp = scalar grep /^\Q$p\E$/s, $obj->properties;
     }
     $obj->error(
         pdebug( 'specified invalid parameter name: %s', PPCDLEVEL1, $p ) )
@@ -241,7 +241,7 @@ sub get {
     pOut();
     pdebug( 'leaving', PPCDLEVEL1 );
 
-    return $valp ? $obj->property($p) : undef;
+    return $valp ? $obj->SUPER::get($p) : undef;
 }
 
 sub set {
@@ -260,7 +260,7 @@ sub set {
     pIn();
 
     if ( defined $p ) {
-        $valp = scalar grep /^\Q$p\E$/s, $obj->propertyNames;
+        $valp = scalar grep /^\Q$p\E$/s, $obj->properties;
     }
     $obj->error(
         pdebug( 'specified invalid parameter name: %s', PPCDLEVEL1, $p ) )
@@ -270,15 +270,15 @@ sub set {
         if (@vals) {
 
             # Set whatever's assigned
-            $rv = $obj->property( $p, @vals );
+            $rv = $obj->SUPER::set( $p, @vals );
         } else {
 
-            # Assume that no values means purge/undef
+            # Assume that no values means empty/undef
             if ( $propTypes{$p} == PPC_SCALAR or $propTypes{$p} == PPC_HDOC )
             {
-                $rv = $obj->property( $p, undef );
+                $rv = $obj->SUPER::set( $p, undef );
             } else {
-                $rv = $obj->purge($p);
+                $rv = $obj->empty($p);
             }
         }
     }
@@ -370,26 +370,25 @@ sub _snarfBlock (\@\$\$$) {
                     pdebug( 'creating property based on prototype %s: %s',
                         PPCDLEVEL3, $proto, $prop );
 
-                    $rv = _declProp(
+                    $rv = _declProperty(
                         $obj,
+                        $prop,
                         CEH_PUB | (
                             $prototypes{$proto} == PPC_HDOC
                             ? PPC_SCALAR
                             : $prototypes{$proto}
                             ),
-                        $prop
                         );
 
                     # Record the prop type
                     if ($rv) {
-                        $settings->store( 'property types',
+                        $settings->merge( 'property types',
                             $prop, $propTypes{$prop} = $prototypes{$proto} );
-                        $preg =
-                            $settings->retrieve( 'prototype registry',
-                            $proto );
+                        ($preg) =
+                            $settings->subset( 'prototype registry', $proto );
                         $preg = [] unless defined $preg;
                         push @$preg, $prop;
-                        $settings->store( 'prototype registry',
+                        $settings->merge( 'prototype registry',
                             $proto => $preg );
                     } else {
                         $obj->error(
@@ -472,7 +471,7 @@ sub _snarfBlock (\@\$\$$) {
 sub _snarfProp {
 
     # Purpose:  Takes the property value and parses according to its type,
-    #           then stores it
+    #           then merges it
     # Returns:  Boolean
     # Usage:    $rv = _snarfProp($obj, $prop, $val);
 
@@ -492,8 +491,8 @@ sub _snarfProp {
     if (   $propTypes{$prop} == PPC_HDOC
         or $propTypes{$prop} == PPC_SCALAR ) {
 
-        # Here Docs and scalars are stored as-is
-        $obj->property( $prop, $val );
+        # Here Docs and scalars are merged as-is
+        $obj->SUPER::set( $prop, $val );
 
     } else {
 
@@ -512,10 +511,10 @@ sub _snarfProp {
 
         }
 
-        # Store the list value
+        # merge the list value
         pdebug( 'storing in %s: %s', PPCDLEVEL3, $prop, @elements );
-        $obj->purge($prop);
-        $obj->property( $prop, @elements );
+        $obj->empty($prop);
+        $obj->SUPER::set( $prop, @elements );
     }
 
     pOut();
@@ -662,13 +661,13 @@ sub reset {
     pdebug( 'entering', PPCDLEVEL1 );
     pIn();
 
-    # Purge all property values
+    # empty all property values
     foreach ( keys %propTypes ) {
-        pdebug( 'clearing stored values for %s', PPCDLEVEL2, $_ );
+        pdebug( 'clearing merged values for %s', PPCDLEVEL2, $_ );
         if ( $propTypes{$_} == PPC_SCALAR or $propTypes{$_} == PPC_HDOC ) {
-            $obj->property( $_, undef );
+            $obj->SUPER::set( $_, undef );
         } else {
-            $obj->purge($_);
+            $obj->empty($_);
         }
     }
     $rv = $obj->parse( $obj->default );
@@ -693,7 +692,7 @@ sub prototyped {
     pdebug( 'entering w/%s', PPCDLEVEL1, $proto );
     pIn();
 
-    %preg = $obj->settings->property('prototype registry');
+    %preg = $obj->settings->get('prototype registry');
 
     if ( defined $proto and length $proto ) {
         if ( exists $preg{$proto} ) {
@@ -724,9 +723,9 @@ sub error {
     my $msg = shift;
 
     if ( defined $msg ) {
-        $obj->settings->property( 'error', $msg );
+        $obj->settings->set( 'error', $msg );
     } else {
-        $msg = $obj->settings->property('error');
+        $msg = $obj->settings->get('error');
     }
 
     return $msg;
@@ -742,7 +741,7 @@ Parse::PlainConfig - Configuration file class
 
 =head1 VERSION
 
-$Id: lib/Parse/PlainConfig.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
+$Id: lib/Parse/PlainConfig.pm, 3.04 2017/02/06 02:58:13 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -844,7 +843,7 @@ B<Parse::PlainConfig> provides a simple way to write a config object class
 that supports all the basic primitive data types (scalar, array, and hashes)
 while allowing for arbitrary delimiters, comment characters, and more.
 
-The use of a B<__DATA__> block to store your default config not only provides 
+The use of a B<__DATA__> block to merge your default config not only provides 
 for a reference config but a convenient way to set default values for 
 parameters and prototypes.  Use of B<__END__> also allows you to append your
 standard POD text to allow for the creation of man pages documenting your
@@ -865,7 +864,7 @@ name instead should keep everything working.
 
 B<Parse::PlainConfig> is a subclass of L<Class::EHierarchy>, and all
 parameters are public properties allowing access to the full set of data-aware
-methods provided by that module (such as B<store>, B<purge>, B<pop>, B<shift>,
+methods provided by that module (such as B<merge>, B<empty>, B<pop>, B<shift>,
 and others).
 
 I/O is also done in a platform-agnostic manner, allowing parsed values to read
@@ -1020,7 +1019,7 @@ type of data structure.
   $conf = new MyConfig;
 
 This creates a new config object based on the specified config class,
-initialized with the defaults stored in B<__DATA__>.  No additional arguments
+initialized with the defaults merged in B<__DATA__>.  No additional arguments
 are supported.  This will fail if the default config is invalid in any way.
 
 =head2 settings
@@ -1046,7 +1045,7 @@ B<__DATA__> section of the config class.
   @val = $config->get($parameter);
   %val = $config->get($parameter);
 
-This returns the stored value(s) for the specified parameter.  It is
+This returns the store value(s) for the specified parameter.  It is
 essentially the same as using the parent class L<property> method, although
 this will not cause the program to L<croak> like L<property> does.  It will
 L<carp>, instead.
@@ -1103,7 +1102,7 @@ following parameters depending on the size of your config files:
 
   $rv = $config->reset;
 
-This method purges the contents of all parameters and prototypes, then applies
+This method emptys the contents of all parameters and prototypes, then applies
 the default settings as found in B<__DATA__>.
 
 =head2 prototyped
