@@ -2,7 +2,7 @@
 #
 # (c) 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Parse/PlainConfig/Settings.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
+# $Id: lib/Parse/PlainConfig/Settings.pm, 3.04 2017/02/06 02:58:13 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -23,7 +23,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-($VERSION) = ( q$Revision: 3.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 3.04 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 use Paranoid;
 use Paranoid::Debug;
@@ -57,57 +57,57 @@ use vars qw(@ISA @_properties @_methods);
 
 sub tabStop {
     my $obj = shift;
-    return $obj->property('tab stop');
+    return $obj->get('tab stop');
 }
 
 sub subindentation {
     my $obj = shift;
-    return $obj->property('subindentation');
+    return $obj->get('subindentation');
 }
 
 sub comment {
     my $obj = shift;
-    return $obj->property('comment');
+    return $obj->get('comment');
 }
 
 sub delimiter {
     my $obj = shift;
-    return $obj->property('delimiter');
+    return $obj->get('delimiter');
 }
 
 sub listDelimiter {
     my $obj = shift;
-    return $obj->property('list delimiter');
+    return $obj->get('list delimiter');
 }
 
 sub hashDelimiter {
     my $obj = shift;
-    return $obj->property('hash delimiter');
+    return $obj->get('hash delimiter');
 }
 
 sub hereDoc {
     my $obj = shift;
-    return $obj->property('here doc');
+    return $obj->get('here doc');
 }
 
 sub propertyTypes {
     my $obj = shift;
-    return $obj->property('property types');
+    return $obj->get('property types');
 }
 
 sub propertyRegexes {
     my $obj = shift;
-    return $obj->property('property regexes');
+    return $obj->get('property regexes');
 }
 
 sub prototypes {
     my $obj = shift;
-    return $obj->property('prototypes');
+    return $obj->get('prototypes');
 }
 
 sub prototypeRegexes {
     my $obj = shift;
-    return $obj->property('prototype regexes');
+    return $obj->get('prototype regexes');
 }
 
 1;
@@ -120,7 +120,7 @@ Parse::PlainConfig::Settings - Settings Class
 
 =head1 VERSION
 
-$Id: lib/Parse/PlainConfig/Settings.pm, 3.03 2016/08/09 16:11:12 acorliss Exp $
+$Id: lib/Parse/PlainConfig/Settings.pm, 3.04 2017/02/06 02:58:13 acorliss Exp $
 
 =head1 SYNOPSIS
 
